package com.chat.nuance.example1;

import android.content.Context;
import android.util.Log;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.io.IOException;
import java.io.InputStream;
import java.util.HashMap;

public class NuanceConfiguration {
    private JSONObject jsonObj;
    private static final NuanceConfiguration nuanceConfig = new NuanceConfiguration();
    private static Context context;

    // Token Parameters
    private String dc,clientID, clientSec, tagServerName;

    // Url Parameters
    private String api, tagServerUrl;

    public void init(Context context){
        if(this.context == null){
            this.context = context;

            jsonObj = getConfiguration();
            setTokenParams(jsonObj);
            setUrlParams(jsonObj);
        }
    }

    private NuanceConfiguration(){}

    public static NuanceConfiguration getInstance(){
        return nuanceConfig;
    }

    private JSONObject getConfiguration() {
        String configData = loadJSONFromAsset();
        try {
            return new JSONObject(configData);
        } catch (JSONException e) {
            throw new RuntimeException("Failed to create JSONObject");
        }
    }

    private String loadJSONFromAsset() {
        String json = null;
        try {
            InputStream is = context.getAssets().open("nuance_configuration.json");
            int size = is.available();
            byte[] buffer = new byte[size];
            is.read(buffer);
            is.close();
            json = new String(buffer, "UTF-8");
        } catch (IOException ex) {
            throw new RuntimeException("nuance_configuration.json file not found.");
        }
        return json;
    }

    public HashMap<String, String> getEngagementParams(){

        if(context == null){
            throw new RuntimeException("Nuance configuration is not initialized, Please call init()");
        }

        HashMap<String, String> engagementParams = new HashMap<>();


        if(!jsonObj.has("engagement_parameters")){
            throw new RuntimeException("Engagement parameters not found");
        }
        JSONObject jsonEngagementObj = jsonObj.optJSONObject("engagement_parameters");
        JSONArray keys = jsonEngagementObj.names();

        for(int i =0; i<keys.length(); i++){
            try {
                String key = keys.getString(i);
                String value = jsonEngagementObj.getString(key);

                engagementParams.put(key, value);
            } catch (JSONException e) {
                throw new RuntimeException("Engagement key not found");
            }

        }
        return engagementParams;
    }

    private void setTokenParams(JSONObject jsonObj){

        if(context == null){
            throw new RuntimeException("Nuance configuration is not initialized, Please call init()");
        }

        if(!jsonObj.has("token_parameters")){
            throw new RuntimeException("Token parameters are required");
        }
        JSONObject jsonTokenObj = jsonObj.optJSONObject("token_parameters");

        try {
            // Token Parameter dc
            if(!jsonTokenObj.has("dc")){
                throw new RuntimeException("Token parameter dc is required");
            }
            this.dc = jsonTokenObj.getString("dc");

            // Token Parameter client-secret
            if(!jsonTokenObj.has("client-secret")){
                throw new RuntimeException("Token parameter client-secret is required");
            }
            this.clientSec = jsonTokenObj.getString("client-secret");

            // Token Parameter client-id
            if(!jsonTokenObj.has("client-id")){
                throw new RuntimeException("Token parameter client-id is required");
            }
            this.clientID = jsonTokenObj.getString("client-id");

            // Token Parameter tag-server-name
            if(!jsonTokenObj.has("tag-server-name")){
                throw new RuntimeException("Token parameter tag-server-name is required");
            }
            this.tagServerName = jsonTokenObj.getString("tag-server-name");

        } catch (JSONException e) {
            throw new RuntimeException("Required token parameters not found");
        }
    }

    private void setUrlParams(JSONObject jsonObj){
        if(context == null){
            throw new RuntimeException("Nuance configuration is not initialized, Please call init()");
        }

        if(!jsonObj.has("external_urls")){
            throw new RuntimeException("External urls not found");
        }
        JSONObject jsonUrlObj = jsonObj.optJSONObject("external_urls");

        try {
            this.api = jsonUrlObj.getString("apiUrl");
            this.tagServerUrl = jsonUrlObj.getString("tagServerUrl");
        } catch (JSONException e) {
            Log.d("NuanceConfiguration", "setUrlParams: Required Urls not found");
        }
    }

    public String getDc(){
        return this.dc;
    }
    public String getClientSec(){
        return this.clientSec;
    }
    public String getClientId(){
        return this.clientID;
    }
    public String getTagServerName(){
        return this.tagServerName;
    }
    public String getApi(){
        return this.api;
    }
    public String getTagServerUrl(){
        return this.tagServerUrl;
    }
}
