package com.nuance.example14;

import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.ProgressBar;
import android.widget.TextView;

import androidx.appcompat.app.AppCompatActivity;

import com.nuance.Listener.OnErrorListener;
import com.nuance.Listener.OnSuccessListener;
import com.nuance.chat.NuanMessaging;
import com.nuance.chat.Responses.Response;
import com.nuance.chat.components.NuanceMessagingFragment;
import com.nuance.translator.NinaMobileController;
import com.nuance.translator.NinaServerConfiguration;
import com.nuance.translator.recognition.RecognitionValues;
import com.nuance.translator.synthesis.SynthesisValues;
import com.nuance.translator.vocabulary.DynamicVocabularyValues;

import org.json.JSONArray;
import org.json.JSONException;

import java.util.HashMap;

public class NMFActivity extends AppCompatActivity implements NuanceMessagingFragment.NuanceMessagingFragmentActionListener,
        NuanceMessagingFragment.TitleUpdateListener {
    private NuanceMessagingFragment nuanceMessagingFragment;
    private ProgressBar progressBar;
    final static HashMap<String, String> engageParams = new HashMap<String, String>();

    static {
        engageParams.put("siteID", "10003715");
        engageParams.put("buID", "13000508");
        engageParams.put("agID", "10004026");
        engageParams.put("brID", "20000");
        engageParams.put("autoID", "18000492");
        engageParams.put("asyncMode", "all");
        engageParams.put("customerName", "TestName");
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_n_m_f);
        initializeNinaMobileController();
        progressBar = findViewById(R.id.progressBar);
        progressBar.setVisibility(View.VISIBLE);
        TextView lblVersion = (TextView) findViewById(R.id.lbl_app_version);
        lblVersion.setText(lblVersion.getText() + " " + NuanMessaging.getVersion());
        method1();
    }

    private void method1() {
        if (NuanMessaging.getInstance().isChatInProgress()) {
            NuanMessaging.getInstance().closeEngagement(new OnSuccessListener<Response>() {
                @Override
                public void onResponse(Response response) {
                    startMessagingFragment(engageParams);
                }
            }, new OnErrorListener() {
                @Override
                public void onErrorResponse(Response response) {
                    startMessagingFragment(engageParams);
                }
            });

        } else {
            startMessagingFragment(engageParams);
        }

    }


    private void startMessagingFragment(HashMap<String, String> engageParams) {
        progressBar.setVisibility(View.GONE);
        if (nuanceMessagingFragment == null) {
            nuanceMessagingFragment = NuanMessaging.getInstance().getBrandedMessagingFragment(NMFActivity.this, engageParams, null, null);
            nuanceMessagingFragment.setNuanceMessagingFragmentActionListener(this);
            nuanceMessagingFragment.setTitleUpdateListener(this);
            getSupportFragmentManager().beginTransaction().add(R.id.container, nuanceMessagingFragment, NuanceMessagingFragment.TAG).commit();
        }
    }

    @Override
    public void onFinish() {
    }

    @Override
    public void refreshMenu() {
        invalidateOptionsMenu();
    }

    @Override
    public void updateTitle(String title) {
    }

    private void initializeNinaMobileController() {
        NuanMessaging.getInstance().initialize(this, "west", "ceapiClientId", "ceapiClientSecret", "bestbrands");
        NuanMessaging.getInstance().setNuanceMessagingTitle("<big><b>British Gas</b></big>");
        NinaServerConfiguration ninaServerConfiguration = new NinaServerConfiguration.NinaServerConfigurationBuilder()
                .setApplicationKey("companyName_appName")
                .setVerificationCode("5796d9e101d5355f5dbf95a3681f6ca5317fd9e96e5ffacac5e1305361a4eb1c")
                .setGateWayScheme("wss")
                .setGateWayAddress("cobra-webapi.nuance.mobi")
                .setGateWayPort(443)
                .setGateWayPath("webapi-platform/websocket")
                .build();
        NinaMobileController.getInstance().initialize(getApplicationContext(), ninaServerConfiguration);

        RecognitionValues recognitionValues = new RecognitionValues.RecognitionValuesBuilder()
                .setActiveDynamicVocabularySets(new String[]{"some_id1"})
                .build();
        NinaMobileController.getInstance().getNinaSetting().setRecognitionValues(recognitionValues);
        SynthesisValues synthesisValues = new SynthesisValues.NinaSynthesisValuesBuilder()
                .setVoice("Tom").build();
        NinaMobileController.getInstance().getNinaSetting().setSynthesisValues(synthesisValues);
        NinaMobileController.getInstance().shouldDebugLog(true);

        try {
            JSONArray jsonArray = new JSONArray("[\n" +
                    "  {\n" +
                    "    \"id\": \"some_id1\",\n" +
                    "    \"type\": \"application/x-nuance-wordset\",\n" +
                    "    \"body\": {\n" +
                    "      \"place-name\": [\n" +
                    "        {\n" +
                    "          \"literal\": \"Los Angeles\",\n" +
                    "          \"spoken\": [\n" +
                    "            \"l a\",\n" +
                    "            \"los angeles\"\n" +
                    "          ]\n" +
                    "        },\n" +
                    "        {\n" +
                    "          \"literal\": \"San Francisco\"\n" +
                    "        }\n" +
                    "      ],\n" +
                    "      \"hockey-team\": [\n" +
                    "        {\n" +
                    "          \"literal\": \"Montreal Canadiens\",\n" +
                    "          \"spoken\": [\n" +
                    "            \"montreal canadiens\",\n" +
                    "            \"habs\"\n" +
                    "          ]\n" +
                    "        },\n" +
                    "        {\n" +
                    "          \"literal\": \"Boston Bruins\"\n" +
                    "        }\n" +
                    "      ]\n" +
                    "    }\n" +
                    "  }\n" +
                    "]");
            DynamicVocabularyValues.DynamicVocabularyValuesBuilder dynamicVocabularyValuesBuilder = new DynamicVocabularyValues.DynamicVocabularyValuesBuilder()
                    .setVocabulary(jsonArray);
            NinaMobileController.getInstance().getNinaSetting().setDynamicVocabularyValues(dynamicVocabularyValuesBuilder.build());

            Log.i("@P@", dynamicVocabularyValuesBuilder.build().toString());
        } catch (JSONException e) {
            e.printStackTrace();
        }

    }
}
