package com.chat.nuance.example4;

import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.Menu;
import android.view.MenuItem;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import androidx.appcompat.widget.Toolbar;

import com.google.android.gms.tasks.OnCompleteListener;
import com.google.android.gms.tasks.Task;
import com.google.android.material.floatingactionbutton.FloatingActionButton;
import com.google.firebase.installations.FirebaseInstallations;
import com.google.firebase.installations.InstallationTokenResult;
import com.nuance.Listener.OnErrorListener;
import com.nuance.Listener.OnSuccessListener;
import com.nuance.chat.NuanMessaging;
import com.nuance.chat.Responses.GetMessageResponse;
import com.nuance.chat.Responses.ProfileResponse;
import com.nuance.chat.Responses.Response;
import com.nuance.profile.ProfileManager;

import org.jetbrains.annotations.NotNull;

import java.util.HashMap;

public class MainActivity extends AppCompatActivity {

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        Toolbar toolbar = (Toolbar) findViewById(R.id.toolbar);
        setSupportActionBar(toolbar);
        ProfileManager.getInstance().setUniqueCustomerId("email","aa@aa.aa");
        if (getIntent().getExtras() != null) {
            for (String key : getIntent().getExtras().keySet()) {
                String value = getIntent().getExtras().getString(key);
                Log.d("@@Test", "Key: " + key + " Value: " + value);
            }

            launchChat(getIntent().getExtras().getString("agentGroupId"), getIntent().getExtras().getString("businessUnitId"), getIntent().getExtras().getString("businessRuleId"));
        }

        if(getIntent().getDataString() != null){
            Log.d("Test",getIntent().getDataString());
        }
        FirebaseInstallations.getInstance().getToken(true).addOnCompleteListener(new OnCompleteListener<InstallationTokenResult>() {
            @Override
            public void onComplete(@NonNull @NotNull Task<InstallationTokenResult> task) {
                if (!task.isSuccessful()) {
                    Log.w("TEST", "getInstanceId failed", task.getException());
                    return;
                }

                // Get new Instance ID token
                String token = task.getResult().getToken();

                NuanMessaging.getInstance().setFcmToken(token);

                //NuanMessaging.getInstance().getProfileManager().setUniqueCustomerId("phone","805");
                NuanMessaging.getInstance().getProfileManager().startSession("10003715", "NuanceDemoApp", ProfileManager.Interval.NOW, new OnSuccessListener<ProfileResponse>() {
                    @Override
                    public void onResponse(ProfileResponse profileResponse) {
                        System.out.print(NuanMessaging.getInstance().getCustomerID());
                    }
                }, new OnErrorListener() {
                    @Override
                    public void onErrorResponse(Response response) {

                    }
                });
            }
        });

        FloatingActionButton fab = (FloatingActionButton) findViewById(R.id.fab);
        fab.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                if(NuanMessaging.getInstance().isChatInProgress()) {
                    NuanMessaging.getInstance().restoreBrandedMessaging(MainActivity.this);
                } else {
                    launchChat("10004026", "13000508", "20000");
                }
            }
        });
        int i=0;
        NuanMessaging.getInstance().setMessageOnMinimizedListener(new OnSuccessListener<GetMessageResponse>() {
            @Override
            public void onResponse(GetMessageResponse response) {

                Log.d("@@Nuan",response.getRawData());
            }
        });
    }

    @Override
    protected void onResume() {
        super.onResume();
        if(NuanMessaging.getInstance().isChatInProgress()) {

        }
    }

    @Override
    protected void onStart() {
        super.onStart();
        if(NuanMessaging.getInstance().isChatInProgress()) {

        }
    }

    private void launchChat(String agID, String buID, String brID) {
        HashMap<String,String> hashMap = new HashMap<String, String>();
        hashMap.put("siteID","10003715");
        hashMap.put("buID",buID);
        hashMap.put("agID",agID);
        hashMap.put("brID",brID);
        hashMap.put("isAsyncEngagement","true");


        HashMap<String, String> datapass = new HashMap<String, String>();
        datapass.put("Test","tesing");
        NuanMessaging.getInstance().launchBrandedMessaging(MainActivity.this, hashMap, null, datapass);
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }
}
