package com.chat.nuance.example7;

import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;


import androidx.appcompat.app.AppCompatActivity;
import androidx.appcompat.widget.Toolbar;

import com.nuance.Listener.OnErrorListener;
import com.nuance.Listener.OnSuccessListener;
import com.nuance.chat.GetMessageAPI;
import com.nuance.chat.NuanMessaging;
import com.nuance.chat.Responses.EngageStatusResponse;
import com.nuance.chat.Responses.GetMessageResponse;
import com.nuance.chat.Responses.Response;
import com.nuance.chat.constants.Constant;
import com.nuance.chat.constants.MessageTypes;
import com.nuance.chat.persistence.Message;
import com.nuance.chatui.CustomerTextInput;
import com.nuance.chatui.GradientSendButton;
import com.nuance.chatui.SimpleSendButton;
import com.nuance.chatui.bubble.BubbleType;
import com.nuance.chatui.bubble.OnCustomerMessage;

import java.util.ArrayList;
import java.util.HashMap;

public class MainActivity extends AppCompatActivity {

    NuanMessaging nuanMessaging;
    MessagesFragment messagesFragment;
    ArrayList<Message> messageList;
    CustomerTextInput customerInputText;
    GradientSendButton gradientSendButton;
    CustomerMessage customerMessage = new CustomerMessage();
    GetMessageAPI getMessageAPI;
    private GetMessageListener getMessageListener;
    public boolean isEngagementQueued;
    public boolean isRotated;
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        messageList = new ArrayList<>();
        nuanMessaging = NuanMessaging.getInstance();
        getMessageAPI = GetMessageAPI.getInstance();
        getMessageListener = new GetMessageListener();
        setContentView(R.layout.activity_main);
        Toolbar toolbar = (Toolbar) findViewById(R.id.toolbar);
        setSupportActionBar(toolbar);
        showListFragment(savedInstanceState, messageList);
        gradientSendButton = (GradientSendButton) findViewById(R.id.sendButton);
        customerInputText = (CustomerTextInput) findViewById(R.id.customer_input_editText);
        customerInputText.setOnCustomerMessage(customerMessage);
        gradientSendButton.setOnCustomerMessage(customerMessage);
        messageList.add(new Message(BubbleType.AGENT_MESSAGE, "Hello how may i help you."));

        HashMap<String, String> hashMap = new HashMap<String, String>();
        hashMap.put("siteID", "10003715");
        hashMap.put("buID", "13000508");
        hashMap.put("agID", "10004026");
        hashMap.put("brID", "20000");
        if (nuanMessaging.isChatInProgress() == false) {
            nuanMessaging.createMessagingEngagment(hashMap, null,
                    new OnSuccessListener<EngageStatusResponse>() {
                        @Override
                        public void onResponse(EngageStatusResponse response) {
                            switch (response.getStatus()) {
                                case Constant.DENIED:
                                    addSystemMessage("Service not available");
                                    break;
                                case Constant.QUEUED:
                                    isEngagementQueued = true;
                                    addSystemMessage("You are in our queue.");
                                case Constant.ACCEPTED:
                                    getMessageAPI.getMessages((com.nuance.Listener.GetMessageListener<GetMessageResponse>) getMessageListener, getMessageListener);
                                    break;

                            }
                        }
                    }, new OnErrorListener() {
                        @Override
                        public void onErrorResponse(Response response) {
                            customerInputText.setEnabled(false);
                            Log.e("Nuance Messaging", "Engage Request:error code:" + response.getStatusCode());

                        }
                    });
                } else {
            if(!isRotated) {
                getMessageAPI.restartGetMessages(true, (com.nuance.Listener.GetMessageListener<GetMessageResponse>) getMessageListener, getMessageListener);
            } else {
                isRotated = false;
                getMessageAPI.restartGetMessages(false, (com.nuance.Listener.GetMessageListener<GetMessageResponse>) getMessageListener, getMessageListener);
            }
        }

    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    private void showListFragment(Bundle savedInstanceState, ArrayList<Message> messageList) {
        if(savedInstanceState != null) {
            isRotated = true;
            messagesFragment = (MessagesFragment) getSupportFragmentManager().getFragment(savedInstanceState, "messageListFrag");
        } else {
            messagesFragment = MessagesFragment.newInstance(messageList);
            getSupportFragmentManager().beginTransaction().add(R.id.messaging_trascript_container, messagesFragment).
                    commit();
        }
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        try {
            nuanMessaging.closeEngagement();
        }catch (IllegalStateException e){

        }
    }

    private void addSystemMessage(String text){
        messagesFragment.addNewItem(new Message(BubbleType.SYSTEM_MESSAGE,text));
    }

    private void addAgentMessage(String text) {
        messagesFragment.addNewItem(new Message(BubbleType.AGENT_MESSAGE,text));
    }

    class CustomerMessage implements OnCustomerMessage {

        @Override
        public void onNewMessage(String s) {
            messagesFragment.addNewItem(new Message(BubbleType.CUSTOMER_MESSAGE,s));
        }

        @Override
        public void onInfoCmd() {

        }
    }
    class GetMessageListener implements  OnSuccessListener<GetMessageResponse>, OnErrorListener {
        @Override
        public void onErrorResponse(Response response) {

        }

        @Override
        public void onResponse(GetMessageResponse getMessageResponse) {
            if(getMessageResponse.getMessageType()== MessageTypes.TYPE_CHATLINE){
                String text = (String)getMessageResponse.getProperty(Constant.MESSAGE_TEXT_PROP);
                if(getMessageResponse.getProperty(Constant.AGENT_ID_PROP) != null) {
                    addAgentMessage(text);
                } else if(getMessageAPI.isRequestFullTranscript()){
                    messagesFragment.addNewItem(new Message(BubbleType.CUSTOMER_MESSAGE,text));
                }

            } else if(getMessageResponse.getMessageType() == MessageTypes.TYPE_STATECHANGE ){

                if(getMessageResponse.getProperty(Constant.STATE_PROP).equals(Constant.STATE_CLOSED)){

                    if(getMessageResponse.getStatusCode() == 401) {

                    } else {
                        addSystemMessage((String) getMessageResponse.getProperty(Constant.DISPLAY_TEXT_PROP));
                        customerInputText.setEnabled(false);
                    }
                } else if(getMessageResponse.getProperty(Constant.STATE_PROP).equals(Constant.STATE_TYPING)){
                    messagesFragment.addNewItem(new Message(BubbleType.TYPING_MESSAGE,(String) getMessageResponse.getProperty(Constant.DISPLAY_TEXT_PROP)));
                } else if(getMessageResponse.getProperty(Constant.STATE_PROP).equals(Constant.STATE_ASSIGNED)) {
                    if(isEngagementQueued){
                        isEngagementQueued = false;
                        addSystemMessage("Agent Now Available");
                    }

                } else if(getMessageResponse.getProperty(Constant.STATE_PROP).equals(Constant.STATE_TRANSFER)){
                    addSystemMessage((String) getMessageResponse.getProperty(Constant.CLIENT_DISPLAY_TEXT_PROP));
                }
            } else if(getMessageResponse.getMessageType() == MessageTypes.TYPE_AUTOMATION_REQUEST) {
                addAgentMessage((String)getMessageResponse.getProperty(Constant.AUTOMATION_DATA_PROP));
            } else if(getMessageResponse.getMessageType() == MessageTypes.TYPE_MEMBER_CONNECTED) {
                addSystemMessage((String) getMessageResponse.getProperty(Constant.DISPLAY_TEXT_PROP));
            } else if(getMessageResponse.getMessageType() == MessageTypes.TYPE_COMMAND) {
                //handle
            }
        }
    }
}
