package com.chat.nuance.example7;

import android.content.Context;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.fragment.app.Fragment;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.nuance.chat.persistence.Message;
import com.nuance.chatui.bubble.BubbleType;

import java.util.ArrayList;
import java.util.List;

public class MessagesFragment extends Fragment {

    private static final String MESSAGE_LIST = "message";
    private List<Message> messageArrayList = new ArrayList<>();
    private TranscriptMessageRecyclerViewAdapter messageRecyclerViewAdapter;
    RecyclerView recyclerView;

    public MessagesFragment() {
    }

    public static MessagesFragment newInstance(ArrayList<Message> arrayList) {
        MessagesFragment fragment = new MessagesFragment();
        Bundle args = new Bundle();
        args.putParcelableArrayList(MESSAGE_LIST, arrayList);
        fragment.setArguments(args);
        return fragment;
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        if (getArguments() != null) {
            messageArrayList = getArguments().getParcelableArrayList(MESSAGE_LIST);
        }

    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.message_list_fragment, container, false);
        if (view instanceof RecyclerView) {
            Context context = view.getContext();
            recyclerView = (RecyclerView) view;
            LinearLayoutManager lm = new LinearLayoutManager(context);
            recyclerView.setLayoutManager(lm);
            messageRecyclerViewAdapter = new TranscriptMessageRecyclerViewAdapter(messageArrayList);
            recyclerView.setAdapter(messageRecyclerViewAdapter);

            recyclerView.addOnLayoutChangeListener(new View.OnLayoutChangeListener() {
                @Override
                public void onLayoutChange(View v, int left, int top, int right, int bottom, int oldLeft, int oldTop, int oldRight, int oldBottom) {
                    if(bottom< oldBottom){
                        scroll();
                    }
                }
            });
        }

        return view;
    }

    public void addNewItem(Message message){
        BubbleType lastItemType = messageArrayList.get(messageArrayList.size()-1).getType();
        if(lastItemType == BubbleType.SYSTEM_MESSAGE || lastItemType == BubbleType.TYPING_MESSAGE){
            messageArrayList.set(messageArrayList.size()-1, message);
            messageRecyclerViewAdapter.notifyItemChanged(messageArrayList.size()-1);
        } else {
            messageArrayList.add(message);
            messageRecyclerViewAdapter.notifyDataSetChanged();
        }
        scroll();
    }

    private void scroll(){
        recyclerView.postDelayed(new Runnable() {
            @Override
            public void run() {
                recyclerView.smoothScrollToPosition(
                        recyclerView.getAdapter().getItemCount() - 1);
            }
        }, 100);
    }


    @Override
    public void onAttach(Context context) {
        super.onAttach(context);

    }

    @Override
    public void onDetach() {
        super.onDetach();
    }

}
